<?php

namespace Drupal\people;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form handler for the people edit forms.
 */
class PeopleForm extends ContentEntityForm {

  /**
   * The people manager service.
   *
   * @var \Drupal\people\PeopleManagerInterface
   */
  protected $peopleManager;

  /**
   * Constructs a BlockContentForm object.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   *   The entity manager.
   * @param \Drupal\people\PeopleManagerInterface $people_manager
   *   The people manager.
   */
  public function __construct(EntityManagerInterface $entity_manager, PeopleManagerInterface $people_manager) {
    parent::__construct($entity_manager);
    $this->peopleManager = $people_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.manager'),
      $container->get('people.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function prepareEntity() {
    parent::prepareEntity();

    $entity = $this->entity;
    if ($organization = $this->peopleManager->currentOrganization()) {
      $entity->organization->target_id = $organization->id();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $people = $this->entity;
    $insert = $people->isNew();
    $people->save();
    $people_link = $people->link($this->t('View'));
    $context = ['%title' => $people->label(), 'link' => $people_link];
    $t_args = ['%title' => $people->link($people->label())];

    if ($insert) {
      $this->logger('people')->notice('People: added %title.', $context);
      drupal_set_message($this->t('People %title has been created.', $t_args));
    }
    else {
      $this->logger('people')->notice('People: updated %title.', $context);
      drupal_set_message($this->t('People %title has been updated.', $t_args));
    }
  }

}
